<template>
    <div class="app-container">
        <div class="filter-container">
            <div class="basic_search">
                <span>单位名称：</span>
                <el-input v-model="listQuery.filter.unitname" class="unit_search_input"></el-input>
            </div>
            <div style="display: block;padding-top: 10px">
                <div class="basic_search">
                    <span>区域：</span>
                    <el-select v-model="listQuery.filter.province" clearable filterable @change="changeArea('province')">
                        <el-option
                            v-for="item in provinceList"
                            :key="item.id"
                            :label="item.name"
                            :value="item.name"
                        >
                        </el-option>
                    </el-select>
                </div>
                <div class="basic_search">
                    <el-select v-model="listQuery.filter.city" prop="city" clearable filterable @change="changeArea('city')">
                        <el-option
                            v-for="item in cityList"
                            :key="item.id"
                            :label="item.name"
                            :value="item.name"
                        >
                        </el-option>
                    </el-select>
                </div>
                <div class="basic_search">
                    <el-select v-model="listQuery.filter.district" clearable filterable @change="changeArea('district')">
                        <el-option
                            v-for="item in districtList"
                            :key="item.id"
                            :label="item.name"
                            :value="item.name"
                        >
                        </el-option>
                    </el-select>
                </div>
                <div class="basic_search">
                    <el-select v-model="listQuery.filter.street"clearable filterable @change="changeArea('street')" >
                        <el-option
                            v-for="item in streetList"
                            :key="item.id"
                            :label="item.name"
                            :value="item.name"
                        >
                        </el-option>
                    </el-select>
                </div>
                <div class="basic_search">
                    <el-select v-model="listQuery.filter.committee" clearable filterable>
                        <el-option
                            v-for="item in committeeList"
                            :key="item.id"
                            :label="item.name"
                            :value="item.name"
                        >
                        </el-option>
                    </el-select>
                </div>
                <el-button  style="margin-left: 10px;" type="primary"  @click="openSupplyUnitForm('新增','')">添加</el-button>
                <el-button  style="margin-left: 10px;" type="primary"  @click="searchData()">查询</el-button>

            </div>


        </div>
        <div class="table_content">
            <el-table
                v-loading="listLoading"
                :key="tableKey"
                :data="carrierList"
                border
                fit
                highlight-current-row
                style="width: 100%;"
            >
                <el-table-column label="序号" type="index" align="center" width="60"/>
                <el-table-column label="单位名称" prop="unitname" align="center">
                </el-table-column>
                <el-table-column label="单位地址" prop="unitaddress" align="center">
                </el-table-column>
                <el-table-column label="法定代表人" prop="representative" align="center">
                </el-table-column>
                <el-table-column label="法定代表人电话" prop="representativephone" align="center">
                </el-table-column>
                <el-table-column label="法定代表人邮箱" prop="representativeemail" align="center">
                </el-table-column>
                <el-table-column label="开户银行" prop="bank" align="center">
                </el-table-column>
                <el-table-column label="操作" align="center" width="180" class-name="small-padding fixed-width">
                    <template slot-scope="scope">
                        <el-button type="text" @click="openSupplyUnitForm('修改',scope.row)">修改</el-button>
                        <el-button type="text" @click="openSupplyUnitForm('查看',scope.row)">查看</el-button>
                        <el-button type="text" @click="delUnit(scope.row)">删除</el-button>
                    </template>
                </el-table-column>
            </el-table>
            <br>
            <el-pagination
                v-show="recordTotal>0"
                :current-page="currentPage"
                :page-sizes="[10, 20, 30, 50]"
                :page-size="pageSize"
                :total="recordTotal"
                layout="total, sizes, prev, pager, next, jumper"
                background
                style="float:right;"
                @size-change="handleSizeChange"
                @current-change="handleCurrentChange"
            />
            <br>
        </div>
        <supplyunitForm ref="supplyUnitForm" @getinfo="getContractUnitList"></supplyunitForm>
    </div>
</template>

<script>
import supplyunitForm from "./components/unitDetailForm/unitDetailForm";
import { computePageCount } from '@/utils'
import { contractUnitList,delContractUnit } from "../../api/contract";
import {getCityListData, getProvinceListData} from "../../api/area";


export default {
    name: "carrier",
    data(){
        return{
            tableKey:0,
            listLoading:false,
            pageSize: 10,
            recordTotal: 0,
            currentPage: 1,
            pageTotal: 0,
            listQuery:{
                filter:{
                  unitname:'',
                },
                pageIndex:1,
                pageSize:10,
            },
            searchContent:'',
            provinceList:[],
            cityList:[],
            districtList:[],
            streetList:[],
            committeeList:[],
            carrierList:[],
        }
    },
  components:{
    supplyunitForm
  },

    created(){
        this.getProvince()
        this.getContractUnitList()
    },
    methods:{
        async getContractUnitList(){
            this.listLoading = true
            let res = await contractUnitList(this.listQuery)
            if(res.data.code === "200"){
                this.recordTotal = res.data.result.total
                this.pageSize = res.data.result.size
                this.pageTotal = computePageCount(res.data.result.total, res.data.result.size)
                this.currentPage = res.data.result.current
                this.carrierList = res.data.result.records
            }
            this.listLoading = false
        },
      delUnit(row){
            this.$confirm('删除此条信息，是否继续','提示',{
                confirmButtonText:'确定',
                cancelButtonText:'取消',
                type:'warning',
            }).then(()=> {
              delContractUnit({id:row.id}).then( ()=>{
                    this.getContractUnitList   ()
                    this.$notify({
                        title:'成功',
                        message:'删除成功',
                        type:'success',
                        duration:2000,
                    })
                })
            })
        },
      async getProvince(){
        let res = await getProvinceListData()
        if(res.data.code === "200"){
          this.provinceList = res.data.result.provinceList
        }
      },//获取省

      async changeArea(value){
        if(value === 'province'){
          this.listQuery.filter.city = ''
          this.listQuery.filter.district = ''
          this.listQuery.filter.street = ''
          this.listQuery.filter.committee = ''
          this.areaListQuery = {
            type: 2,
            parenttype: 1,
            parentname: this.listQuery.filter.province,
          }
          let res = await getCityListData(this.areaListQuery)
          if(res.data.code === "200"){
            this.cityList = res.data.result
          }
        }else if(value === 'city'){
          this.listQuery.filter.district = ''
          this.listQuery.filter.street = ''
          this.listQuery.filter.committee = ''
          this.areaListQuery = {
            type: 3,
            parenttype: 2,
            parentname: this.listQuery.filter.city,
          }
          let res = await getCityListData(this.areaListQuery)
          if(res.data.code === "200"){
            this.districtList = res.data.result
          }
        }else if(value === 'district'){
          this.listQuery.filter.street = ''
          this.listQuery.filter.committee = ''
          this.areaListQuery = {
            type: 4,
            parenttype: 3,
            parentname: this.listQuery.filter.district,
          }
          let res = await getCityListData(this.areaListQuery)
          if(res.data.code === "200"){
            this.streetList = res.data.result
          }
        }else if(value === 'street'){
          this.listQuery.filter.committee = ''
          this.areaListQuery = {
            type: 5,
            parenttype: 4,
            parentname: this.listQuery.filter.street,
          }
          let res = await getCityListData(this.areaListQuery)
          if(res.data.code === "200"){
            this.committeeList = res.data.result
          }
        }
      },//市、镇、街道、委员会
        openSupplyUnitForm(title,value){
            this.$refs.supplyUnitForm.showUnitForm(title,value)
        },
        searchData(){
            this.getContractUnitList()
        },
        handleSizeChange: function(val) {
            this.pageSize = val
            this.currentPage = 1
            this.getContractUnitList()
        },
        handleCurrentChange: function(val) {
            this.currentPage = val
            this.getContractUnitList()
        },
    }
}
</script>

<style scoped>
    .basic_search{
        display:inline-block;
    }
.unit_search_input{
    width:200px;
}
/deep/ .table_content{
    padding:0px;
}
</style>
